from a10sdk.common.A10BaseClass import A10BaseClass


class VrrpA(A10BaseClass):
    
    """Class Description::
    Enable VRRP-A group traps.

    Class vrrp-a supports CRUD Operations and inherits from `common/A10BaseClass`.
    This class is the `"PARENT"` class for this module.`

    :param active: {"default": 0, "optional": true, "type": "number", "description": "Enable VRRP-A active trap", "format": "flag"}
    :param standby: {"default": 0, "optional": true, "type": "number", "description": "Enable VRRP-A standby trap", "format": "flag"}
    :param all: {"default": 0, "optional": true, "type": "number", "description": "Enable all VRRP-A group traps", "format": "flag"}
    :param DeviceProxy: The device proxy for REST operations and session handling. Refer to `common/device_proxy.py`

    

    URL for this object::
    `https://<Hostname|Ip address>//axapi/v3/snmp-server/enable/traps/vrrp-a`.

    

    
    """
    def __init__(self, **kwargs):
        self.ERROR_MSG = ""
        self.required=[]
        self.b_key = "vrrp-a"
        self.a10_url="/axapi/v3/snmp-server/enable/traps/vrrp-a"
        self.DeviceProxy = ""
        self.active = ""
        self.standby = ""
        self.A10WW_all = ""

        for keys, value in kwargs.items():
            setattr(self,keys, value)





from a10sdk.common.A10BaseClass import A10BaseClass


class AddressCfg(A10BaseClass):
    
    """This class does not support CRUD Operations please use parent.

    :param link_local: {"default": 0, "type": "number", "description": "Configure an IPv6 link local address", "format": "flag"}
    :param anycast: {"default": 0, "type": "number", "description": "Configure an IPv6 anycast address", "format": "flag"}
    :param ipv6_addr: {"type": "string", "description": "Set the IPv6 address of an interface", "format": "ipv6-address-plen"}
    :param DeviceProxy: The device proxy for REST operations and session handling. Refer to `common/device_proxy.py`

    

    
    """
    def __init__(self, **kwargs):
        self.ERROR_MSG = ""
        
        self.b_key = "address-cfg"
        self.DeviceProxy = ""
        self.link_local = ""
        self.anycast = ""
        self.ipv6_addr = ""

        for keys, value in kwargs.items():
            setattr(self,keys, value)


class Ipv6(A10BaseClass):
    
    """Class Description::
    Global IPv6 configuration subcommands.

    Class ipv6 supports CRUD Operations and inherits from `common/A10BaseClass`.
    This class is the `"PARENT"` class for this module.`

    :param address_cfg: {"minItems": 1, "items": {"type": "object"}, "uniqueItems": true, "type": "array", "array": [{"properties": {"link-local": {"default": 0, "type": "number", "description": "Configure an IPv6 link local address", "format": "flag"}, "anycast": {"default": 0, "type": "number", "description": "Configure an IPv6 anycast address", "format": "flag"}, "ipv6-addr": {"type": "string", "description": "Set the IPv6 address of an interface", "format": "ipv6-address-plen"}, "optional": true}}]}
    :param ipv6_enable: {"default": 0, "optional": true, "type": "number", "description": "Enable IPv6 processing", "format": "flag"}
    :param DeviceProxy: The device proxy for REST operations and session handling. Refer to `common/device_proxy.py`

    

    URL for this object::
    `https://<Hostname|Ip address>//axapi/v3/interface/tunnel/{ifnum}/ipv6`.

    

    
    """
    def __init__(self, **kwargs):
        self.ERROR_MSG = ""
        self.required=[]
        self.b_key = "ipv6"
        self.a10_url="/axapi/v3/interface/tunnel/{ifnum}/ipv6"
        self.DeviceProxy = ""
        self.address_cfg = []
        self.ipv6_enable = ""

        for keys, value in kwargs.items():
            setattr(self,keys, value)





from a10sdk.common.A10BaseClass import A10BaseClass


class SessionList(A10BaseClass):
    
    """This class does not support CRUD Operations please use parent.

    :param name: {"minLength": 1, "maxLength": 63, "type": "string", "format": "string"}
    :param cfg_mode: {"minLength": 1, "maxLength": 63, "type": "string", "format": "string"}
    :param src_ip: {"minLength": 1, "maxLength": 63, "type": "string", "format": "string"}
    :param sid: {"minLength": 1, "maxLength": 63, "type": "string", "format": "string"}
    :param type: {"minLength": 1, "maxLength": 63, "type": "string", "format": "string"}
    :param DeviceProxy: The device proxy for REST operations and session handling. Refer to `common/device_proxy.py`

    

    
    """
    def __init__(self, **kwargs):
        self.ERROR_MSG = ""
        
        self.b_key = "session-list"
        self.DeviceProxy = ""
        self.name = ""
        self.cfg_mode = ""
        self.src_ip = ""
        self.sid = ""
        self.A10WW_type = ""

        for keys, value in kwargs.items():
            setattr(self,keys, value)


class Oper(A10BaseClass):
    
    """This class does not support CRUD Operations please use parent.

    :param session_list: {"minItems": 1, "items": {"type": "object"}, "uniqueItems": true, "type": "array", "array": [{"properties": {"name": {"minLength": 1, "maxLength": 63, "type": "string", "format": "string"}, "optional": true, "cfg_mode": {"minLength": 1, "maxLength": 63, "type": "string", "format": "string"}, "src_ip": {"minLength": 1, "maxLength": 63, "type": "string", "format": "string"}, "sid": {"minLength": 1, "maxLength": 63, "type": "string", "format": "string"}, "type": {"minLength": 1, "maxLength": 63, "type": "string", "format": "string"}}}]}
    :param DeviceProxy: The device proxy for REST operations and session handling. Refer to `common/device_proxy.py`

    

    
    """
    def __init__(self, **kwargs):
        self.ERROR_MSG = ""
        
        self.b_key = "oper"
        self.DeviceProxy = ""
        self.session_list = []

        for keys, value in kwargs.items():
            setattr(self,keys, value)


class AdminSession(A10BaseClass):
    
    """Class Description::
    Operational Status for the object admin-session.

    Class admin-session supports CRUD Operations and inherits from `common/A10BaseClass`.
    This class is the `"PARENT"` class for this module.`

    :param DeviceProxy: The device proxy for REST operations and session handling. Refer to `common/device_proxy.py`

    

    URL for this object::
    `https://<Hostname|Ip address>//axapi/v3/admin-session/oper`.

    

    
    """
    def __init__(self, **kwargs):
        self.ERROR_MSG = ""
        self.required=[]
        self.b_key = "admin-session"
        self.a10_url="/axapi/v3/admin-session/oper"
        self.DeviceProxy = ""
        self.oper = {}

        for keys, value in kwargs.items():
            setattr(self,keys, value)





from a10sdk.common.A10BaseClass import A10BaseClass


class Export(A10BaseClass):
    
    """    :param all: {"default": 0, "optional": true, "type": "number", "description": "System support messages", "format": "flag"}
    :param remote_file: {"optional": true, "type": "string", "description": "Remote url", "format": "url"}
    :param use_mgmt_port: {"default": 0, "optional": true, "type": "number", "description": "Use management port as source port", "format": "flag"}
    :param DeviceProxy: The device proxy for REST operations and session handling. Refer to `common/device_proxy.py`

Class Description::
    Export cached log items to the specified destination.

    Class export supports CRUD Operations and inherits from `common/A10BaseClass`.
    This class is the `"PARENT"` class for this module.`

    

    URL for this object::
    `https://<Hostname|Ip address>//axapi/v3/logging/export`.

    

    
    """
    def __init__(self, **kwargs):
        self.ERROR_MSG = ""
        self.required=[]
        self.b_key = "export"
        self.a10_url="/axapi/v3/logging/export"
        self.DeviceProxy = ""
        self.A10WW_all = ""
        self.remote_file = ""
        self.use_mgmt_port = ""

        for keys, value in kwargs.items():
            setattr(self,keys, value)





from a10sdk.common.A10BaseClass import A10BaseClass


class StartupConfig(A10BaseClass):
    
    """    :param default: {"description": "Default startup-config", "partition-visibility": "shared", "default": 0, "type": "number", "format": "flag", "optional": true}
    :param secondary: {"default": 0, "optional": true, "type": "number", "description": "Create link in secondary partition", "format": "flag"}
    :param primary: {"default": 0, "optional": true, "type": "number", "description": "Create link in primary partition", "format": "flag"}
    :param file_name: {"description": "Local Configuration Profile Name", "format": "string", "minLength": 1, "optional": true, "maxLength": 31, "type": "string"}
    :param DeviceProxy: The device proxy for REST operations and session handling. Refer to `common/device_proxy.py`

Class Description::
    Startup Configuration.

    Class startup-config supports CRUD Operations and inherits from `common/A10BaseClass`.
    This class is the `"PARENT"` class for this module.`

    

    URL for this object::
    `https://<Hostname|Ip address>//axapi/v3/link/startup-config`.

    

    
    """
    def __init__(self, **kwargs):
        self.ERROR_MSG = ""
        self.required=[]
        self.b_key = "startup-config"
        self.a10_url="/axapi/v3/link/startup-config"
        self.DeviceProxy = ""
        self.default = ""
        self.secondary = ""
        self.primary = ""
        self.file_name = ""

        for keys, value in kwargs.items():
            setattr(self,keys, value)





from a10sdk.common.A10BaseClass import A10BaseClass


class Static(A10BaseClass):
    
    """Class Description::
    Static MAC commands.

    Class static supports CRUD Operations and inherits from `common/A10BaseClass`.
    This class is the `"PARENT"` class for this module.`

    :param dest: {"default": 0, "optional": true, "type": "number", "description": "Trap MAC with this DA to CPU", "format": "flag"}
    :param mac: {"optional": false, "type": "string", "description": "Configure a Static MAC address", "format": "mac-address"}
    :param vlan: {"description": "VLAN Id", "format": "number", "optional": false, "maximum": 4094, "minimum": 2, "type": "number", "$ref": "/axapi/v3/network/vlan"}
    :param port: {"optional": true, "type": "number", "description": "Ethernet Port on which the Address is applicable (Port Value (Defualt VLAN is 1))", "format": "interface"}
    :param DeviceProxy: The device proxy for REST operations and session handling. Refer to `common/device_proxy.py`

    

    URL for this object::
    `https://<Hostname|Ip address>//axapi/v3/network/mac-address/static/{mac}+{vlan}`.

    

    
    """
    def __init__(self, **kwargs):
        self.ERROR_MSG = ""
        self.required = [ "mac","vlan"]

        self.b_key = "static"
        self.a10_url="/axapi/v3/network/mac-address/static/{mac}+{vlan}"
        self.DeviceProxy = ""
        self.dest = ""
        self.mac = ""
        self.vlan = ""
        self.port = ""

        for keys, value in kwargs.items():
            setattr(self,keys, value)





from a10sdk.common.A10BaseClass import A10BaseClass


class Protocol(A10BaseClass):
    
    """Class Description::
    Configure netflow protocol version to use, default is netflow v9.

    Class protocol supports CRUD Operations and inherits from `common/A10BaseClass`.
    This class is the `"PARENT"` class for this module.`

    :param version: {"description": "v9: \"Netflow version 9\"; v10: \"Netflow version 10 (IPFIX)\"; ", "format": "enum", "default": "v9", "type": "string", "enum": ["v9", "v10"], "optional": true}
    :param DeviceProxy: The device proxy for REST operations and session handling. Refer to `common/device_proxy.py`

    

    URL for this object::
    `https://<Hostname|Ip address>//axapi/v3/netflow/monitor/{name}/protocol`.

    

    
    """
    def __init__(self, **kwargs):
        self.ERROR_MSG = ""
        self.required=[]
        self.b_key = "protocol"
        self.a10_url="/axapi/v3/netflow/monitor/{name}/protocol"
        self.DeviceProxy = ""
        self.version = ""

        for keys, value in kwargs.items():
            setattr(self,keys, value)





from a10sdk.common.A10BaseClass import A10BaseClass


class IdleTimeout(A10BaseClass):
    
    """Class Description::
    Configure TCP established-session idle timeout for IPv4 and IPv6.

    Class idle-timeout supports CRUD Operations and inherits from `common/A10BaseClass`.
    This class is the `"PARENT"` class for this module.`

    :param idle_timeout_val_port_range: {"description": "Set Idle timeout for IPv4 and IPv6 TCP established sessions (Idle timeout for IPv4 and IPv6 TCP established sessions (default: 300 seconds))", "format": "number", "default": 300, "optional": true, "maximum": 3780, "minimum": 60, "type": "number"}
    :param port: {"description": "Single Destination Port or Port Range Start", "format": "number", "type": "number", "maximum": 65535, "minimum": 1, "optional": false}
    :param port_end: {"description": "Port Range End", "format": "number", "type": "number", "maximum": 65535, "minimum": 1, "optional": false}
    :param DeviceProxy: The device proxy for REST operations and session handling. Refer to `common/device_proxy.py`

    

    URL for this object::
    `https://<Hostname|Ip address>//axapi/v3/cgnv6/stateful-firewall/tcp/idle-timeout/{port}+{port_end}`.

    

    
    """
    def __init__(self, **kwargs):
        self.ERROR_MSG = ""
        self.required = [ "port","port_end"]

        self.b_key = "idle-timeout"
        self.a10_url="/axapi/v3/cgnv6/stateful-firewall/tcp/idle-timeout/{port}+{port_end}"
        self.DeviceProxy = ""
        self.idle_timeout_val_port_range = ""
        self.port = ""
        self.port_end = ""

        for keys, value in kwargs.items():
            setattr(self,keys, value)





from a10sdk.common.A10BaseClass import A10BaseClass


class Level(A10BaseClass):
    
    """Class Description::
    Set logging level which sent to email address.

    Class level supports CRUD Operations and inherits from `common/A10BaseClass`.
    This class is the `"PARENT"` class for this module.`

    :param email_levelname: {"optional": true, "enum": ["emergency", "alert", "critical", "notification"], "type": "string", "description": "'emergency': System unusable log messages      (severity=0); 'alert': Action must be taken immediately   (severity=1); 'critical': Critical conditions      (severity=2); 'notification': Normal but significant conditions (severity=5); ", "format": "enum"}
    :param DeviceProxy: The device proxy for REST operations and session handling. Refer to `common/device_proxy.py`

    

    URL for this object::
    `https://<Hostname|Ip address>//axapi/v3/logging/email/level`.

    

    
    """
    def __init__(self, **kwargs):
        self.ERROR_MSG = ""
        self.required=[]
        self.b_key = "level"
        self.a10_url="/axapi/v3/logging/email/level"
        self.DeviceProxy = ""
        self.email_levelname = ""

        for keys, value in kwargs.items():
            setattr(self,keys, value)





from a10sdk.common.A10BaseClass import A10BaseClass


class Priority(A10BaseClass):
    
    """Class Description::
    HA VRRP-A Global Commands.

    Class priority supports CRUD Operations and inherits from `common/A10BaseClass`.
    This class is the `"PARENT"` class for this module.`

    :param priority_value: {"description": "VRRP-A priorty. help-val Priority, default is 150", "format": "number", "default": 150, "optional": true, "maximum": 255, "minimum": 1, "type": "number"}
    :param DeviceProxy: The device proxy for REST operations and session handling. Refer to `common/device_proxy.py`

    

    URL for this object::
    `https://<Hostname|Ip address>//axapi/v3/vrrp-a/vrid/{vrid_val}/priority`.

    

    
    """
    def __init__(self, **kwargs):
        self.ERROR_MSG = ""
        self.required=[]
        self.b_key = "priority"
        self.a10_url="/axapi/v3/vrrp-a/vrid/{vrid_val}/priority"
        self.DeviceProxy = ""
        self.priority_value = ""

        for keys, value in kwargs.items():
            setattr(self,keys, value)





from a10sdk.common.A10BaseClass import A10BaseClass


class MacAgeTime(A10BaseClass):
    
    """Class Description::
    Set Aging period for all MAC Interfaces.

    Class mac-age-time supports CRUD Operations and inherits from `common/A10BaseClass`.
    This class is the `"PARENT"` class for this module.`

    :param aging_time: {"description": "Set aging period in seconds for all MAC interfaces (default 300 seconds)", "format": "number", "default": 300, "optional": true, "maximum": 600, "minimum": 10, "type": "number"}
    :param DeviceProxy: The device proxy for REST operations and session handling. Refer to `common/device_proxy.py`

    

    URL for this object::
    `https://<Hostname|Ip address>//axapi/v3/network/mac-age-time`.

    

    
    """
    def __init__(self, **kwargs):
        self.ERROR_MSG = ""
        self.required=[]
        self.b_key = "mac-age-time"
        self.a10_url="/axapi/v3/network/mac-age-time"
        self.DeviceProxy = ""
        self.aging_time = ""

        for keys, value in kwargs.items():
            setattr(self,keys, value)





from a10sdk.common.A10BaseClass import A10BaseClass


class Tftp(A10BaseClass):
    
    """Class Description::
    TFTP client configuration.

    Class tftp supports CRUD Operations and inherits from `common/A10BaseClass`.
    This class is the `"PARENT"` class for this module.`

    :param blksize: {"description": "TFTP client block size value (Block size (Blksize/Max file size. Example: 1K/64M, 8K/512M, 32K/2048M))", "format": "number", "type": "number", "maximum": 32768, "minimum": 512, "optional": true}
    :param DeviceProxy: The device proxy for REST operations and session handling. Refer to `common/device_proxy.py`

    

    URL for this object::
    `https://<Hostname|Ip address>//axapi/v3/tftp`.

    

    
    """
    def __init__(self, **kwargs):
        self.ERROR_MSG = ""
        self.required=[]
        self.b_key = "tftp"
        self.a10_url="/axapi/v3/tftp"
        self.DeviceProxy = ""
        self.blksize = ""

        for keys, value in kwargs.items():
            setattr(self,keys, value)


